# Contributing to JupyterHealth

Welcome! As a [Jupyter](https://jupyter.org) project,
you can follow the [Jupyter contributor guide](https://jupyter.readthedocs.io/en/latest/contributing/content-contributor.html).

JupyterHealth is part of the [JupyterHub subproject](https://jupyterhub-team-compass.readthedocs.io/en/latest/contribute/guide.html).

Make sure to also follow [Project Jupyter's Code of Conduct](https://github.com/jupyter/governance/blob/HEAD/conduct/code_of_conduct.md)
for a friendly and welcoming collaborative environment.

If you need some help, feel free to ask on [Zulip](https://jupyter.zulipchat.com/#narrow/channel/469744-jupyterhub/) or [Discourse](https://discourse.jupyter.org/).
